@@ -1,5 +1,35 @@
 var NAVTREEINDEX16 =
 {
+"group__spa__system.html#gad8592bcc0072a7f3e01c1c599c31a59a":[10,8,9,7,6],
+"group__spa__system.html#gadc27e9cd52e02e882a9cff73cc39b84e":[10,8,9,7,5],
+"group__spa__system.html#gae3bdff54f3f6b5970f995d7dd1e0397a":[10,8,9,7,19],
+"group__spa__system.html#gae7496c8f3c9e1adf18c6fa58df0fd464":[10,8,9,7,8],
+"group__spa__system.html#gaea351cfc19dfe7def75926678ef7a61c":[10,8,9,7,14],
+"group__spa__system.html#gaed2ee0d164d71468cbebc3d3d1644abd":[10,8,9,7,23],
+"group__spa__system.html#gaed5715eaa56338c8d14d4f43e9880782":[10,8,9,7,28],
+"group__spa__system.html#gaf4ac27f90f1eee63c0b3f10e7b97999a":[10,8,9,7,18],
+"group__spa__system.html#gafc0c4bc774b7d7f571cfc311223cd01c":[10,8,9,7,34],
+"group__spa__system.html#gaff95a55ae068dc73d2434f5bf40bdb9a":[10,8,9,7,29],
+"group__spa__thread.html":[10,8,9,8],
+"group__spa__thread.html#ga087f55566e08c2bb1536574b7556a66f":[10,8,9,8,13],
+"group__spa__thread.html#ga13cf7d6799ad80fe7e3f69874032d529":[10,8,9,8,12],
+"group__spa__thread.html#ga36d6661f31950920b85cd0c48fc68a33":[10,8,9,8,4],
+"group__spa__thread.html#ga4f716da417d838544df4e82f4670b79c":[10,8,9,8,6],
+"group__spa__thread.html#ga5d2d0635caeef22aaa5a63681255219d":[10,8,9,8,9],
+"group__spa__thread.html#ga6680e7f42845ca460cdaa93abd568e02":[10,8,9,8,5],
+"group__spa__thread.html#ga7454dd6c4ac2967b5c53936dc6ec00b5":[10,8,9,8,7],
+"group__spa__thread.html#ga7c5acfdece976cd3f7b12dee4ddb3e41":[10,8,9,8,10],
+"group__spa__thread.html#ga8dcf8fcd02dbf3c2c49afe37e40b6a43":[10,8,9,8,11],
+"group__spa__thread.html#gaa3418c60a3ab55c44596d0c37ff0fe1b":[10,8,9,8,8],
+"group__spa__thread.html#gae1224b4702957d8a48f7c17cf350f5a2":[10,8,9,8,14],
+"group__spa__types.html":[10,8,8,12],
+"group__spa__types.html#ga0c6d1b17fc516da2e38cea3e1c7c859c":[10,8,8,12,24],
+"group__spa__types.html#ga12e7f34d2ebf7bb4ad1b14997148383f":[10,8,8,12,8],
+"group__spa__types.html#ga21cc1e946168521828401b4b652c3318":[10,8,8,12,7],
+"group__spa__types.html#ga2262de66172c201319e7336253600f31":[10,8,8,12,22],
+"group__spa__types.html#ga35e8b94254c7e556e3838eb8ab5167c3":[10,8,8,12,27],
+"group__spa__types.html#ga3f8207af24a34e29769be91b720c5191":[10,8,8,12,29],
+"group__spa__types.html#ga4aae17a0b82f8be6d450a8fa3a102225":[10,8,8,12,14],
 "group__spa__types.html#ga4fabe70032a577729bfaa7e1cb231ac6":[10,8,8,12,18],
 "group__spa__types.html#ga5d6f54a630998568dc7b1a3515a434bf":[10,8,8,12,15],
 "group__spa__types.html#ga690dba641d1bb8f54c7b0ca7478e53cf":[10,8,8,12,23],
@@ -75,87 +105,90 @@ var NAVTREEINDEX16 =
 "group__spa__utils.html":[10,8,8],
 "group__spa__utils__defs.html":[10,8,8,1],
 "group__spa__utils__defs.html#ga006941b3f6423cec7b170b4434d8a799":[10,8,8,1,8],
-"group__spa__utils__defs.html#ga007f98725701a4b6debe365c7a5e0bbe":[10,8,8,1,77],
-"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84":[10,8,8,1,54],
+"group__spa__utils__defs.html#ga007f98725701a4b6debe365c7a5e0bbe":[10,8,8,1,80],
+"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84":[10,8,8,1,55],
 "group__spa__utils__defs.html#ga06647c110a0382a09bea681a14634f64":[10,8,8,1,19],
-"group__spa__utils__defs.html#ga1179685eef5a041a5c8e60a9a6483048":[10,8,8,1,23],
-"group__spa__utils__defs.html#ga1b605788d4782d77eb54b75f258413b9":[10,8,8,1,34],
-"group__spa__utils__defs.html#ga1f57dfee056b657ddcd2bc69a7f45bce":[10,8,8,1,53],
-"group__spa__utils__defs.html#ga2157cfb3de1793302e5d08958bdc8ab2":[10,8,8,1,66],
-"group__spa__utils__defs.html#ga26f69327ba25a67c5120805511190740":[10,8,8,1,60],
-"group__spa__utils__defs.html#ga2c939bee0863eddd75b264b2aaf316e0":[10,8,8,1,57],
+"group__spa__utils__defs.html#ga1179685eef5a041a5c8e60a9a6483048":[10,8,8,1,24],
+"group__spa__utils__defs.html#ga1b605788d4782d77eb54b75f258413b9":[10,8,8,1,35],
+"group__spa__utils__defs.html#ga1f57dfee056b657ddcd2bc69a7f45bce":[10,8,8,1,54],
+"group__spa__utils__defs.html#ga2157cfb3de1793302e5d08958bdc8ab2":[10,8,8,1,69],
+"group__spa__utils__defs.html#ga26f69327ba25a67c5120805511190740":[10,8,8,1,63],
+"group__spa__utils__defs.html#ga2c939bee0863eddd75b264b2aaf316e0":[10,8,8,1,59],
 "group__spa__utils__defs.html#ga33e30c1bdbba747c8c00077913d48411":[10,8,8,1,21],
-"group__spa__utils__defs.html#ga3404aa33acd9e8316fb33ebd146446f0":[10,8,8,1,59],
-"group__spa__utils__defs.html#ga3625c72ccb164919faaf2a3c5a37e9c2":[10,8,8,1,74],
+"group__spa__utils__defs.html#ga3404aa33acd9e8316fb33ebd146446f0":[10,8,8,1,62],
+"group__spa__utils__defs.html#ga34890f84380ed041625fc0a252186bf2":[10,8,8,1,22],
+"group__spa__utils__defs.html#ga3625c72ccb164919faaf2a3c5a37e9c2":[10,8,8,1,77],
 "group__spa__utils__defs.html#ga3bca1a11d1c7e8404f9456580acf0676":[10,8,8,1,10],
-"group__spa__utils__defs.html#ga3d65c899d0f8937244ed2893d1841f6f":[10,8,8,1,44],
-"group__spa__utils__defs.html#ga3fecbba7e4f85f539f62c8db39f12b0a":[10,8,8,1,55],
-"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5":[10,8,8,1,69],
-"group__spa__utils__defs.html#ga4a50fbd4b694e2826233b6d54ef3b5a8":[10,8,8,1,62],
-"group__spa__utils__defs.html#ga4a52677c41f0a787a3c6624f18647cb6":[10,8,8,1,41],
+"group__spa__utils__defs.html#ga3d65c899d0f8937244ed2893d1841f6f":[10,8,8,1,45],
+"group__spa__utils__defs.html#ga3fecbba7e4f85f539f62c8db39f12b0a":[10,8,8,1,57],
+"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5":[10,8,8,1,72],
+"group__spa__utils__defs.html#ga4a50fbd4b694e2826233b6d54ef3b5a8":[10,8,8,1,65],
+"group__spa__utils__defs.html#ga4a52677c41f0a787a3c6624f18647cb6":[10,8,8,1,42],
 "group__spa__utils__defs.html#ga57aec3d89182594c8fef7be284f41fff":[10,8,8,1,11],
 "group__spa__utils__defs.html#ga58dddf4d57e29beade3b44e156dea532":[10,8,8,1,15],
-"group__spa__utils__defs.html#ga59196e4cfb0d8c0a8bdcd909cbbea334":[10,8,8,1,25],
-"group__spa__utils__defs.html#ga5e46f399b745cda80c6a5a8ab8d5d14f":[10,8,8,1,27],
-"group__spa__utils__defs.html#ga6212956dcff36c69fa954f66efaefbcf":[10,8,8,1,72],
-"group__spa__utils__defs.html#ga6259b69a24b203050fe69cacac57748a":[10,8,8,1,38],
-"group__spa__utils__defs.html#ga632087e970399228667a768ba8424f4e":[10,8,8,1,68],
-"group__spa__utils__defs.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0":[10,8,8,1,39],
-"group__spa__utils__defs.html#ga6c3f9f95123f53da37d2bd173bd17ed1":[10,8,8,1,36],
+"group__spa__utils__defs.html#ga59196e4cfb0d8c0a8bdcd909cbbea334":[10,8,8,1,26],
+"group__spa__utils__defs.html#ga5e46f399b745cda80c6a5a8ab8d5d14f":[10,8,8,1,28],
+"group__spa__utils__defs.html#ga6212956dcff36c69fa954f66efaefbcf":[10,8,8,1,75],
+"group__spa__utils__defs.html#ga6259b69a24b203050fe69cacac57748a":[10,8,8,1,39],
+"group__spa__utils__defs.html#ga632087e970399228667a768ba8424f4e":[10,8,8,1,71],
+"group__spa__utils__defs.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0":[10,8,8,1,40],
+"group__spa__utils__defs.html#ga6c3f9f95123f53da37d2bd173bd17ed1":[10,8,8,1,37],
 "group__spa__utils__defs.html#ga796e3d4570d8d539ea5886074a646a11":[10,8,8,1,16],
-"group__spa__utils__defs.html#ga7b184a799c7168d95deaecab5208f557":[10,8,8,1,45],
-"group__spa__utils__defs.html#ga7b3174639eb92d4c045a2bbc72a035df":[10,8,8,1,37],
-"group__spa__utils__defs.html#ga7f23cca5e034297bbd1b6860d1dbfdbc":[10,8,8,1,22],
+"group__spa__utils__defs.html#ga7b184a799c7168d95deaecab5208f557":[10,8,8,1,46],
+"group__spa__utils__defs.html#ga7b3174639eb92d4c045a2bbc72a035df":[10,8,8,1,38],
+"group__spa__utils__defs.html#ga7f23cca5e034297bbd1b6860d1dbfdbc":[10,8,8,1,23],
 "group__spa__utils__defs.html#ga895eccfd8032e0e9eec102e3b8442f12":[10,8,8,1,17],
-"group__spa__utils__defs.html#ga933e7dba5e09dd618617b7b16c0d42fc":[10,8,8,1,50],
-"group__spa__utils__defs.html#ga9a615b131c891caac9a73e05b35da09c":[10,8,8,1,63],
-"group__spa__utils__defs.html#ga9f2fae4a58cc2e3fdf568d1afc9dc7c1":[10,8,8,1,78],
-"group__spa__utils__defs.html#gaa360562916c7e9ab66865f277477f4e6":[10,8,8,1,67],
-"group__spa__utils__defs.html#gaa3a2b836ca54d95f207f5557988db748":[10,8,8,1,65],
+"group__spa__utils__defs.html#ga933e7dba5e09dd618617b7b16c0d42fc":[10,8,8,1,51],
+"group__spa__utils__defs.html#ga9a615b131c891caac9a73e05b35da09c":[10,8,8,1,66],
+"group__spa__utils__defs.html#ga9f2fae4a58cc2e3fdf568d1afc9dc7c1":[10,8,8,1,81],
+"group__spa__utils__defs.html#gaa360562916c7e9ab66865f277477f4e6":[10,8,8,1,70],
+"group__spa__utils__defs.html#gaa3a2b836ca54d95f207f5557988db748":[10,8,8,1,68],
 "group__spa__utils__defs.html#gaa44a69e371d934ab026ae08af1d9b67e":[10,8,8,1,7],
-"group__spa__utils__defs.html#gaa495b586c261831b67f09c7f9851aa05":[10,8,8,1,28],
-"group__spa__utils__defs.html#gaa92b4913ce779aa401cc714ae829eace":[10,8,8,1,32],
-"group__spa__utils__defs.html#gaabdb5fd45bca56878896d7c28204fb88":[10,8,8,1,35],
-"group__spa__utils__defs.html#gaad6949f0b0a59d29fdf35ff11ebf83cb":[10,8,8,1,26],
-"group__spa__utils__defs.html#gab30712bed8289c9218eb66d9bfeeab78":[10,8,8,1,47],
-"group__spa__utils__defs.html#gab4c957beedd4012fd0513f174d7b8b1a":[10,8,8,1,61],
-"group__spa__utils__defs.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca":[10,8,8,1,58],
-"group__spa__utils__defs.html#gac1ac8f034b73e453c531d928cdfdd8b7":[10,8,8,1,51],
-"group__spa__utils__defs.html#gac30327f8b5e6a9c6f9129a73581d09dc":[10,8,8,1,64],
-"group__spa__utils__defs.html#gac8080acabcd35c560a15df5e1801afa1":[10,8,8,1,30],
-"group__spa__utils__defs.html#gac894bd2d39b2644e1bacf4b11c0a187d":[10,8,8,1,49],
-"group__spa__utils__defs.html#gac8965bea56eb75da08e84a547bee992e":[10,8,8,1,48],
+"group__spa__utils__defs.html#gaa495b586c261831b67f09c7f9851aa05":[10,8,8,1,29],
+"group__spa__utils__defs.html#gaa92b4913ce779aa401cc714ae829eace":[10,8,8,1,33],
+"group__spa__utils__defs.html#gaabdb5fd45bca56878896d7c28204fb88":[10,8,8,1,36],
+"group__spa__utils__defs.html#gaad6949f0b0a59d29fdf35ff11ebf83cb":[10,8,8,1,27],
+"group__spa__utils__defs.html#gab30712bed8289c9218eb66d9bfeeab78":[10,8,8,1,48],
+"group__spa__utils__defs.html#gab4c957beedd4012fd0513f174d7b8b1a":[10,8,8,1,64],
+"group__spa__utils__defs.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca":[10,8,8,1,61],
+"group__spa__utils__defs.html#gac1ac8f034b73e453c531d928cdfdd8b7":[10,8,8,1,52],
+"group__spa__utils__defs.html#gac30327f8b5e6a9c6f9129a73581d09dc":[10,8,8,1,67],
+"group__spa__utils__defs.html#gac8080acabcd35c560a15df5e1801afa1":[10,8,8,1,31],
+"group__spa__utils__defs.html#gac894bd2d39b2644e1bacf4b11c0a187d":[10,8,8,1,50],
+"group__spa__utils__defs.html#gac8965bea56eb75da08e84a547bee992e":[10,8,8,1,49],
 "group__spa__utils__defs.html#gacbdd2b8d9e9137bbbd9a38f495c80263":[10,8,8,1,5],
-"group__spa__utils__defs.html#gacc9914448bc9fd68ae5ccf004c401bcb":[10,8,8,1,42],
+"group__spa__utils__defs.html#gacc9914448bc9fd68ae5ccf004c401bcb":[10,8,8,1,43],
 "group__spa__utils__defs.html#gace48f5bc6836a62c328fcac938f8ea6e":[10,8,8,1,14],
 "group__spa__utils__defs.html#gaceee1eb1469c2ab68034f5619913bc0d":[10,8,8,1,9],
-"group__spa__utils__defs.html#gad485e752b9b897f6434724f669ba72ae":[10,8,8,1,52],
-"group__spa__utils__defs.html#gad5b23b2094b330aacd6489da1c8fa7b7":[10,8,8,1,43],
-"group__spa__utils__defs.html#gadc0cd747e27d01b74cdd6d3131e3df27":[10,8,8,1,56],
-"group__spa__utils__defs.html#gadd03b1b1f299d9249de66ff32bc34569":[10,8,8,1,75],
-"group__spa__utils__defs.html#gae2c26bfcbc2a33bcfae86018b35fab20":[10,8,8,1,73],
-"group__spa__utils__defs.html#gae8ab0b793d870a9725897e695454c12b":[10,8,8,1,24],
-"group__spa__utils__defs.html#gae8d35b670e70b6cdba489ca76b5791d4":[10,8,8,1,70],
-"group__spa__utils__defs.html#gaec22d2ead4ec1771760219dc16f24709":[10,8,8,1,29],
+"group__spa__utils__defs.html#gad199e69d5c112451d5a1abf07b9e0b8b":[10,8,8,1,60],
+"group__spa__utils__defs.html#gad485e752b9b897f6434724f669ba72ae":[10,8,8,1,53],
+"group__spa__utils__defs.html#gad5b23b2094b330aacd6489da1c8fa7b7":[10,8,8,1,44],
+"group__spa__utils__defs.html#gadc0cd747e27d01b74cdd6d3131e3df27":[10,8,8,1,58],
+"group__spa__utils__defs.html#gadd03b1b1f299d9249de66ff32bc34569":[10,8,8,1,78],
+"group__spa__utils__defs.html#gae2c26bfcbc2a33bcfae86018b35fab20":[10,8,8,1,76],
+"group__spa__utils__defs.html#gae8ab0b793d870a9725897e695454c12b":[10,8,8,1,25],
+"group__spa__utils__defs.html#gae8d35b670e70b6cdba489ca76b5791d4":[10,8,8,1,73],
+"group__spa__utils__defs.html#gaec22d2ead4ec1771760219dc16f24709":[10,8,8,1,30],
 "group__spa__utils__defs.html#gaf296ce57d6de2645675d2c89fdc8af0a":[10,8,8,1,6],
 "group__spa__utils__defs.html#gaf42b2cfc208dc17d25624d84f962b25d":[10,8,8,1,13],
 "group__spa__utils__defs.html#gaf5c3a152070995c325caaaf0333269c0":[10,8,8,1,18],
-"group__spa__utils__defs.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e":[10,8,8,1,76],
-"group__spa__utils__defs.html#gaf8cdb131feb79dfd1d9d1097cb89c052":[10,8,8,1,33],
-"group__spa__utils__defs.html#gaf9f1e071334f25ea8580f2509d17fcdd":[10,8,8,1,40],
-"group__spa__utils__defs.html#gafa109f3532687323c8f8340f18a15220":[10,8,8,1,71],
-"group__spa__utils__defs.html#gafa5449ce6a2352b7966fa923892a46fa":[10,8,8,1,31],
+"group__spa__utils__defs.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e":[10,8,8,1,79],
+"group__spa__utils__defs.html#gaf88c39fbcce246ddc0e78a934dda87cb":[10,8,8,1,56],
+"group__spa__utils__defs.html#gaf8cdb131feb79dfd1d9d1097cb89c052":[10,8,8,1,34],
+"group__spa__utils__defs.html#gaf9f1e071334f25ea8580f2509d17fcdd":[10,8,8,1,41],
+"group__spa__utils__defs.html#gafa109f3532687323c8f8340f18a15220":[10,8,8,1,74],
+"group__spa__utils__defs.html#gafa5449ce6a2352b7966fa923892a46fa":[10,8,8,1,32],
 "group__spa__utils__defs.html#gafd41067bab5e0c66b38886f672702dd4":[10,8,8,1,20],
-"group__spa__utils__defs.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca":[10,8,8,1,46],
+"group__spa__utils__defs.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca":[10,8,8,1,47],
 "group__spa__utils__defs.html#gafdd52836cf3dfdc12328615ac44c18e0":[10,8,8,1,12],
-"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[10,8,8,1,78,0],
-"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[10,8,8,1,78,1],
+"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[10,8,8,1,81,0],
+"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[10,8,8,1,81,1],
 "index.html":[],
 "index.html#autotoc_md0":[0],
 "index.html#autotoc_md1":[1],
 "index.html#autotoc_md2":[2],
 "index.html#autotoc_md3":[3],
-"local-v4l2_8c-example.html":[13,23],
+"local-v4l2_8c-example.html":[13,24],
 "modules.html":[10],
 "page_access.html":[5,5],
 "page_access.html#autotoc_md10":[5,5,0],
@@ -216,38 +249,5 @@ var NAVTREEINDEX16 =
 "page_library.html#autotoc_md48":[5,9,3],
 "page_library.html#autotoc_md49":[5,9,3,0],
 "page_library.html#autotoc_md50":[5,9,3,1],
-"page_library.html#autotoc_md51":[5,9,3,2],
-"page_library.html#autotoc_md52":[5,9,3,3],
-"page_library.html#autotoc_md53":[5,9,3,4],
-"page_library.html#autotoc_md54":[5,9,3,5],
-"page_library.html#autotoc_md55":[5,9,3,6],
-"page_library.html#autotoc_md56":[5,9,3,7],
-"page_library.html#autotoc_md57":[5,9,3,8],
-"page_library.html#autotoc_md58":[5,9,3,9],
-"page_library.html#autotoc_md59":[5,9,4],
-"page_library.html#autotoc_md60":[5,9,4,0],
-"page_library.html#autotoc_md61":[5,9,4,1],
-"page_library.html#autotoc_md62":[5,9,5],
-"page_library.html#autotoc_md63":[5,9,6],
-"page_library.html#autotoc_md64":[5,9,7],
-"page_man_pipewire_1.html":[5,12,0],
-"page_man_pipewire_conf_5.html":[5,12,2],
-"page_man_pipewire_pulse_1.html":[5,12,1],
-"page_man_pw_cat_1.html":[5,12,3],
-"page_man_pw_cli_1.html":[5,12,4],
-"page_man_pw_dot_1.html":[5,12,5],
-"page_man_pw_jack_1.html":[5,12,12],
-"page_man_pw_link_1.html":[5,12,6],
-"page_man_pw_metadata_1.html":[5,12,7],
-"page_man_pw_mididump_1.html":[5,12,8],
-"page_man_pw_mon_1.html":[5,12,9],
-"page_man_pw_profiler_1.html":[5,12,10],
-"page_man_pw_top_1.html":[5,12,11],
-"page_midi.html":[5,7],
-"page_midi.html#autotoc_md20":[5,7,0],
-"page_midi.html#autotoc_md21":[5,7,0,0],
-"page_midi.html#autotoc_md22":[5,7,0,1],
-"page_midi.html#autotoc_md23":[5,7,0,2],
-"page_midi.html#autotoc_md24":[5,7,0,3],
-"page_midi.html#autotoc_md25":[5,7,0,4]
+"page_library.html#autotoc_md51":[5,9,3,2]
 };
